@@ -20,9 +20,9 @@
 #include "book.h"
 #include "reader.h"
 
-#include "common/base64.h"
-#include "common/regexTools.h"
-#include "common/networkTools.h"
+#include "tools/base64.h"
+#include "tools/regexTools.h"
+#include "tools/networkTools.h"
 
 #include <pugixml.hpp>
 
@@ -60,11 +60,6 @@ bool Book::update(const kiwix::Book& other)
     m_name = other.m_name;
   }
 
-  if (m_indexPath.empty()) {
-    m_indexPath = other.m_indexPath;
-    m_indexType = other.m_indexType;
-  }
-
   if (m_faviconMimeType.empty()) {
     m_favicon = other.m_favicon;
     m_faviconMimeType = other.m_faviconMimeType;
@@ -101,14 +96,6 @@ void Book::updateFromXml(const pugi::xml_node& node, const std::string& baseDir)
     path = computeAbsolutePath(baseDir, path);
   }
   m_path = path;
-  path = ATTR("indexPath");
-  if (!path.empty()) {
-    if (isRelativePath(path)) {
-      path = computeAbsolutePath(baseDir, path);
-    }
-    m_indexPath = path;
-    m_indexType = XAPIAN;
-  }
   m_title = ATTR("title");
   m_name = ATTR("name");
   m_tags = ATTR("tags");
@@ -131,6 +118,14 @@ void Book::updateFromXml(const pugi::xml_node& node, const std::string& baseDir)
 #undef ATTR
 
 
+static std::string fromOpdsDate(const std::string& date)
+{
+  //The opds date use the standard <YYYY>-<MM>-<DD>T<HH>:<mm>:<SS>Z
+  //and we want <YYYY>-<MM>-<DD>. That's easy, let's take the first 10 char
+  return date.substr(0, 10);
+}
+
+
 #define VALUE(name) node.child(name).child_value()
 void Book::updateFromOpds(const pugi::xml_node& node, const std::string& urlHost)
 {
@@ -141,7 +136,7 @@ void Book::updateFromOpds(const pugi::xml_node& node, const std::string& urlHost
   m_title = VALUE("title");
   m_description = VALUE("description");
   m_language = VALUE("language");
-  m_date = VALUE("updated");
+  m_date = fromOpdsDate(VALUE("updated"));
   m_creator = node.child("author").child("name").child_value();
   for(auto linkNode = node.child("link"); linkNode;
            linkNode = linkNode.next_sibling("link")) {
@@ -186,13 +181,6 @@ void Book::setPath(const std::string& path)
    : path;
 }
 
-void Book::setIndexPath(const std::string& indexPath)
-{
-  m_indexPath = isRelativePath(indexPath)
-    ? computeAbsolutePath(getCurrentDirectory(), indexPath)
-    : indexPath;
-}
-
 const std::string& Book::getFavicon() const {
   if (m_favicon.empty() && !m_faviconUrl.empty()) {
     try {
