@@ -9,7 +9,7 @@ ARCHIVE_NAME=deps_${TRAVIS_OS_NAME}_${PLATFORM}_${REPO_NAME}.tar.xz
 cd $HOME
 if [[ "$TRAVIS_OS_NAME" == "osx" ]]
 then
-  pip3 install meson
+  pip3 install meson==0.49.2
 
   wget https://github.com/ninja-build/ninja/releases/download/v1.8.2/ninja-mac.zip
   unzip ninja-mac.zip ninja
@@ -18,7 +18,7 @@ else
   python3.5 get-pip.py --user
 
   python3.5 -m pip install --user --upgrade pip
-  python3.5 -m pip install --user meson
+  python3.5 -m pip install --user meson==0.49.2
 
   wget https://github.com/ninja-build/ninja/releases/download/v1.8.2/ninja-linux.zip
   unzip ninja-linux.zip ninja
